{% load aa_forum %}

<script
    src="{% aa_forum_static 'aa_forum/javascript/aa-forum-oembed.min.js' %}"
    integrity="sha512-Bx4gKE2Etird5yHyEUzbHIYTIuJ+9ck6+60OnSlNpMI2en5BhFDOnC14wbeCv2X9zU9j/h6hLElPfpm1sKs3SQ=="
    crossorigin="anonymous"
></script>
