{% load aa_forum %}

<link
    rel="stylesheet"
    href="{% aa_forum_static 'aa_forum/css/aa-forum.min.css' %}"
    integrity="sha512-lfyZT614KJRI1WN1kPfyPUCMA33HL6wO9cY/P1m6ZfNTUUnUZiAH58fwgHZ33Cncr1T/eEzkZhNeVpUgAj9new=="
    crossorigin="anonymous"
>
