{% load static %}

<script
    src="{% static 'aa_forum/libs/sumoselect/3.4.9/jquery.sumoselect.min.js' %}"
    integrity="sha512-+Ea4TZ8vBWO588N7H6YOySCtkjerpyiLnV7bgqwrQF+vqR8+q/InGK9WDZx5d6VtdGRoV6uLd5Dwz2vE7EL3oQ=="
    crossorigin="anonymous"
></script>
